@@ -154,6 +154,15 @@ class BRMAName(Enum):
     WORTHING = "Worthing"
     YEOVIL = "Yeovil"
     YORK = "York"
+    # Northern Ireland
+    BELFAST = "Belfast"
+    LOUGH_NEAGH_LOWER = "Lough Neagh Lower"
+    LOUGH_NEAGH_UPPER = "Lough Neagh Upper"
+    NORTH = "North (NI)"
+    NORTH_WEST = "North West (NI)"
+    SOUTH = "South (NI)"
+    SOUTH_EAST = "South East (NI)"
+    SOUTH_WEST = "South West (NI)"
 
 
 class LocalAuthority(Enum):
@@ -545,5 +554,6 @@ class local_authority(Variable):
     possible_values = LocalAuthority
     default_value = LocalAuthority.MAIDSTONE
     entity = Household
-    label = "The Local Authority for the household"
+    label = "Local Authority"
+    documentation = "The local authority for this household (this is often the same as your Broad Rental Market Area, but may differ)."
     definition_period = YEAR
